@@ -3,10 +3,19 @@ from django.conf import settings
 from errors import WsResponseError, WsInvocationError
 import httplib, json, proxy_server
 
-def invoke_backend_service(method, function_path, json_data=dict(), request=None, response_token=True, public=False):
-    if hasattr(settings, 'BACKEND_HOST') and hasattr(settings, 'BACKEND_PORT'):
-        conn = httplib.HTTPConnection(settings.BACKEND_HOST, settings.BACKEND_PORT)
-        
+def invoke_backend_service(method, function_path, json_data=dict(), request=None, response_token=True, public=False, secure=False):
+    if hasattr(settings, 'BACKEND_HOST'):
+        if secure:
+            if hasattr(settings, 'BACKEND_PORT'):
+                conn = httplib.HTTPSConnection(settings.BACKEND_HOST, settings.BACKEND_PORT)
+            else:
+                conn = httplib.HTTPSConnection(settings.BACKEND_HOST)
+        else:
+            if hasattr(settings, 'BACKEND_PORT'):
+                conn = httplib.HTTPConnection(settings.BACKEND_HOST, settings.BACKEND_PORT)
+            else:
+                raise WsInvocationError('No port supplied')
+            
         if request is not None:
             headers = proxy_server.RESTFUL_HEADER
             headers[proxy_server.USER_TOKEN] = request.user.pk
